==> hbase-2.4.9-src.tar.gz: hbase-2.4.9/hbase-hbtop/src/main/java/org/apache/hadoop/hbase/hbtop/mode/DrillDownInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.hbtop.mode;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;

import org.apache.hadoop.hbase.hbtop.RecordFilter;
import org.apache.yetus.audience.InterfaceAudience;


/**
 * Information about drilling down.
 *
 * When drilling down, going to next {@link Mode} with initial {@link RecordFilter}s.
 */
@InterfaceAudience.Private
public class DrillDownInfo {
  private final Mode nextMode;
  private final List<RecordFilter> initialFilters;

  public DrillDownInfo(Mode nextMode, List<RecordFilter> initialFilters) {
    this.nextMode = Objects.requireNonNull(nextMode);
    this.initialFilters = Collections.unmodifiableList(new ArrayList<>(initialFilters));
  }

  public Mode getNextMode() {
    return nextMode;
  }

  public List<RecordFilter> getInitialFilters() {
    return initialFilters;
  }
}

==> hbase-2.5.12-src.tar.gz: hbase-2.5.12/hbase-hbtop/src/main/java/org/apache/hadoop/hbase/hbtop/mode/DrillDownInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.hbtop.mode;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import org.apache.hadoop.hbase.hbtop.RecordFilter;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Information about drilling down. When drilling down, going to next {@link Mode} with initial
 * {@link RecordFilter}s.
 */
@InterfaceAudience.Private
public class DrillDownInfo {
  private final Mode nextMode;
  private final List<RecordFilter> initialFilters;

  public DrillDownInfo(Mode nextMode, List<RecordFilter> initialFilters) {
    this.nextMode = Objects.requireNonNull(nextMode);
    this.initialFilters = Collections.unmodifiableList(new ArrayList<>(initialFilters));
  }

  public Mode getNextMode() {
    return nextMode;
  }

  public List<RecordFilter> getInitialFilters() {
    return initialFilters;
  }
}
